@@ -15,13 +15,15 @@ POSTGRES_TYPES = {
     'timestamp': 'timestamptz',
     'date': 'date',
     'link': 'integer',
+    'array': 'json',
     'object': 'json',
     'id': 'serial',
 }
 
 REDSHIFT_TYPES = {
     **POSTGRES_TYPES,
-    'object': 'text',
+    'array': 'varchar(1024)',
+    'object': 'varchar(1024)',
     'id': 'int identity(1, 1) not null',
 }
 
@@ -34,3 +36,25 @@ FK_TYPES = {
     'serial': 'bigint',
     'int identity(1, 1) not null': 'bigint',
 }
+
+COLUMNS_TYPES_PREFERENCE = {
+    'null': -1,
+    'boolean': 0,
+    'bool': 0,
+    'enum': 1,
+    'link': 2,
+    'integer': 3,
+    'bigint': 4,
+    'number': 5,
+    'float': 5,
+    'date': 5,
+    'timestamp': 6,
+    'timestamptz': 6,
+    'array': 7,
+    'text': 8,
+    'string': 8,
+    'object': 9,
+    'json': 9,
+    'id': 10,
+    'serial': 10,
+}
